==> nextcloud-app-spreed-4.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/is.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Sannreyna SSL-skilríki",
    "Delete server" : "Eyða þjóni",
    "Add new server" : "Bæta við nýjum þjóni",
    "Saved" : "Vistað",
    "Shared secret" : "Sameiginlegur leynilykill",
    "TURN server shared secret" : "Sameiginlegur leynilykill á TURN-þjóni",
    "TURN server protocols" : "Samskiptareglur TURN-þjóns",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "Aðeins UDP",
    "TCP only" : "Aðeins TCP",
    "New public conversation" : "Nýtt opinbert samtal",
    "New group conversation" : "Nýtt hópsamtal",
    "New conversation …" : "Nýtt samtal…",
    "Screensharing is not supported by your browser." : "Deiling á skjá er ekki studd í vafranum þínum",
    "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
    "Screensharing options" : "Valkostir skjádeilingar",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
    "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
    "Participants" : "Þátttakendur",
    "Chat" : "Spjall",
    "Talk" : "Spjalla",
    "Waiting for {participantName} to join the call …" : "Bíð eftir að {participantName} komi inn í símtalið …",
    "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
    "Exit fullscreen (f)" : "Hætta í skjáfylli (f)",
    "Fullscreen (f)" : "Fylla skjáinn (f)",
    "Mute audio (m)" : "Þagga hljóð (m)",
    "Unmute audio (m)" : "Afþagga hljóð (m)",
    "No audio" : "Ekkert hljóð",
    "Disable video (v)" : "Gera myndskeið óvirk (v)",
    "Enable video (v)" : "Virkja myndskeið (v)",
    "Set your name in the chat window so other participants can identify you better." : "Settu nafnið þitt í spjallgluggann svo að aðrir þáttakendur eigi auðveldara með að þekkja þig.",
    "No Camera" : "Engin myndavél",
    "Enable screensharing" : "Virkja skjádeilingu",
    "Copy" : "Afrita",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
    "This conversation has ended" : "Þessu samtali er lokið",
    "Share screen" : "Deila skjá",
    "Show your screen" : "Birta skjáinn þinn",
    "Stop screensharing" : "Hætta skjádeilingu",
    "Please enter the password for this call" : "Settu inn lykilorðið fyrir þetta símtal",
    "Password required" : "Lykilorðs er krafist",
    "Password" : "Lykilorð",
    "Cancel" : "Hætta við",
    "Submit" : "Senda inn",
    "Leave call" : "Hætta símtali",
    "Join call" : "Taka þátt í símtali",
    "Start call" : "Hefja samtal",
    "Share link" : "Deila tengli",
    "Change password" : "Breyta lykilorði",
    "Set password" : "Stilltu lykilorð",
    "Name" : "Nafn",
    "Conversation name" : "Heiti samtals",
    "Rename" : "Endurnefna",
    "Copy link" : "Afrita tengil",
    "Conversation with {name}" : "Samtal við {name}",
    "Error occurred while setting password" : "Villa kom upp við að stilla lykilorð",
    "Link copied!" : "Tengill afritaður!",
    "You" : "Þú",
    "No messages yet, start the conversation!" : "Engin skilaboð ennþá, byrjaðu umræðuna!",
    "New message …" : "Ný skilaboð …",
    "Send" : "Senda",
    "Guest" : "Gestur",
    "[Unknown user name]" : "[nafn óþekkts notanda]",
    "Today" : "Í dag",
    "Yesterday" : "Í gær",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Villa kom upp við að senda inn skilaboð",
    "Edit" : "Breyta",
    "moderator" : "umsjónarmaður",
    "Demote from moderator" : "Láta hætta sem umsjónarmann",
    "Promote to moderator" : "Gera að umsjónarmanni",
    "Remove participant" : "Fjarlægja þátttakanda",
    "Add participant …" : "Bæta við þátttakanda…",
    "Leave conversation" : "Hætta í samtali",
    "Delete conversation" : "Eyða samtali",
    "No other people in this call" : "Engir aðrir í þessu símtali",
    "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
    "Close" : "Loka",
    "Waiting for camera and microphone permissions" : "Bíð eftir heimildum fyrir hljóðnema og myndavél",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Til að nota þetta forrit, þarftu að gefa vafranum þínum heimild til að nota hljóðnema og myndavél.",
    "Disable video" : "Gera myndskeið óvirk",
    "Show screen" : "Birta skjá",
    "Enable video" : "Virkja myndskeið",
    "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
    "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
    "Access to microphone & camera was denied" : "Aðgangur að hljóðnema og myndavél var ekki heimilaður",
    "WebRTC is not supported in your browser" : "WebRTC er ekki stutt í vafranum þínum",
    "Please use a different browser like Firefox or Chrome" : "Veldu einhvern annan vafra eins og Firefox eða Chrome",
    "Error while accessing microphone & camera" : "Villa kom upp þegar reynt var að opna hljóðnema og myndavél",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ekki stutt í vafranum þínum :-/",
    "{participantName}'s screen" : "Skjár {participantName}",
    "Guest's screen" : "Skjár gests",
    "Your screen" : "Skjárinn þinn",
    "a conversation" : "samtal",
    "(Duration %s)" : "(tímalengd %s)",
    "You attended a call with {user1}" : "Þú varst í símtali við {user1}",
    "_%n guest_::_%n guests_" : ["%n gestur","%n gestir"],
    "You attended a call with {user1} and {user2}" : "Þú varst í símtali við {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Þú varst í símtali við {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Þú varst í símtali við {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Þú varst í símtali við {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n annar","%n aðrir"],
    "{actor} invited you to {call}" : "{actor} bauð þér að taka þátt í {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Þér var boðið að taka þátt í <strong>spjallsvæði</strong> eða hefur fengið <strong>upphringingu</strong>",
    "Talk to %s" : "Tala við %s",
    "_%n other guest_::_%n other guests_" : ["%n annar gestur","%n aðrir gestir"],
    ", " : ", ",
    "%s mentioned you in a private conversation" : "%s minntist á þig í einkasamtali",
    "{user} mentioned you in a private conversation" : "{user} minntist á þig í einkasamtali",
    "%s mentioned you in a group conversation: %s" : "%s minntist á þig í hópsamtali: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} minntist á þig í hópsamtali: {call}",
    "%s mentioned you in a group conversation" : "%s minntist á þig í hópsamtali",
    "{user} mentioned you in a group conversation" : "{user} minntist á þig í hópsamtali",
    "A guest mentioned you in a group conversation: %s" : "Gestur minntist á þig í hópsamtali: %s",
    "A guest mentioned you in a group conversation: {call}" : "Gestur minntist á þig í hópsamtali: {call}",
    "A guest mentioned you in a group conversation" : "Gestur minntist á þig í hópsamtali",
    "%s invited you to a private conversation" : "%s bauð þér að taka þátt í einkasímtali",
    "{user} invited you to a private conversation" : "{user} bauð þér að taka þátt í einkasímtali",
    "%s invited you to a group conversation: %s" : "%s bauð þér að taka þátt í hópsímtali: %s",
    "{user} invited you to a group conversation: {call}" : "{user} bauð þér að taka þátt í hópsímtali: {call}",
    "%s invited you to a group conversation" : "%s bauð þér að taka þátt í hópsímtali",
    "{user} invited you to a group conversation" : "{user} bauð þér að taka þátt í hópsímtali",
    "{user} wants to talk with you" : "{user} vill tala við þig",
    "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
    "A group call has started" : "Hópsímtal er byrjað",
    "Video & audio-conferencing using WebRTC" : "Mynd- og hljóðfundir með WebRTC",
    "This call is password-protected" : "Þetta samtal er er varið með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "STUN servers" : "STUN-þjónar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
    "TURN server" : "TURN-þjónn",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Video calls" : "Myndsímtöl",
    "(group)" : "(hópur)",
    "New public call" : "Nýtt opinbert símtal",
    "Looking great today! :)" : "Lítur vel út í dag! :)",
    "Time to call your friends" : "Tími til að hringja í vinina",
    "You can set your name on the top right of this page so other participants can identify you better." : "Þú getur stillt þetta þannig að nafnið þitt birtist efst til hægri á þessari síðu svo að aðrir þáttakendur eigi auðveldara með að þekkja þig.",
    "This call has ended" : "Þessu símtali er lokið",
    "Saving failed" : "Vistun mistókst",
    "Add person" : "Bæta við aðila",
    "and you" : "og þú",
    "Please adjust your configuration" : "Endilega athugaðu uppsetninguna þína",
    "{actor} invited you to a private call" : "{actor} bauð þér að taka þátt í einkasímtali",
    "{actor} invited you to a group call" : "{actor} bauð þér að taka þátt í hópsímtali",
    "{actor} invited you to the call {call}" : "{actor} bauð þér að taka þátt í símtalinu {call}",
    "You were invited to a <strong>video call</strong>" : "Þér var boðið að taka þátt í <strong>myndsímtali</strong>",
    "Video call" : "Myndsímtal",
    "Invalid format, must be stunserver:port." : "Ógilt snið, verður að vera stun-þjónn:gátt.",
    "Invalid port specified." : "Ógild gátt tiltekin.",
    "Invalid protocols specified." : "Ógildir samskiptamátar tilgreindir.",
    "%s invited you to a private call" : "%s bauð þér að taka þátt í einkasímtali",
    "{user} invited you to a private call" : "{user} bauð þér að taka þátt í einkasímtali",
    "%s invited you to a group call: %s" : "%s bauð þér að taka þátt í hópsímtali: %s",
    "{user} invited you to a group call: {call}" : "{user} bauð þér að taka þátt í hópsímtali: {call}",
    "%s invited you to a group call" : "%s bauð þér að taka þátt í hópsímtali",
    "{user} invited you to a group call" : "{user} bauð þér að taka þátt í hópsímtali",
    "Fullscreen" : "Fylla skjáinn",
    "Mute audio" : "Þagga hljóð",
    "Smile in 3… 2… 1!" : "Brosa eftir 3… 2… 1!",
    "Choose person …" : "Veldu einstakling …",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN-þjónninn er nauðsynlegur til að þáttakendur geti tengst símtölum. TURN-þjónninn tryggir að tengingin virki jafnvel í gegnum eldveggi.",
    "STUN server" : "STUN-þjónn",
    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-spreed-4.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/is.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Sannreyna SSL-skilríki",
    "Delete server" : "Eyða þjóni",
    "Add new server" : "Bæta við nýjum þjóni",
    "Saved" : "Vistað",
    "STUN server URL" : "URL-slóð STUN-þjóns",
    "TURN server URL" : "URL-slóð TURN-þjóns",
    "Shared secret" : "Sameiginlegur leynilykill",
    "TURN server shared secret" : "Sameiginlegur leynilykill á TURN-þjóni",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "Aðeins UDP",
    "TCP only" : "Aðeins TCP",
    "Test server" : "Prófa þjón",
    "TURN server protocols" : "Samskiptareglur TURN-þjóns",
    "New public conversation" : "Nýtt opinbert samtal",
    "New group conversation" : "Nýtt hópsamtal",
    "{name} (public)" : "{name} (opinbert)",
    "New conversation …" : "Nýtt samtal…",
    "Screensharing is not supported by your browser." : "Deiling á skjá er ekki studd í vafranum þínum",
    "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
    "Screensharing options" : "Valkostir skjádeilingar",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
    "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
    "Participants" : "Þátttakendur",
    "Chat" : "Spjall",
    "Talk" : "Spjalla",
    "Waiting for {participantName} to join the call …" : "Bíð eftir að {participantName} komi inn í símtalið …",
    "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
    "Exit fullscreen (f)" : "Hætta í skjáfylli (f)",
    "Fullscreen (f)" : "Fylla skjáinn (f)",
    "Mute audio (m)" : "Þagga hljóð (m)",
    "Unmute audio (m)" : "Afþagga hljóð (m)",
    "No audio" : "Ekkert hljóð",
    "Disable video (v)" : "Gera myndskeið óvirk (v)",
    "Enable video (v)" : "Virkja myndskeið (v)",
    "Set your name in the chat window so other participants can identify you better." : "Settu nafnið þitt í spjallgluggann svo að aðrir þáttakendur eigi auðveldara með að þekkja þig.",
    "No Camera" : "Engin myndavél",
    "Enable screensharing" : "Virkja skjádeilingu",
    "Copy" : "Afrita",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
    "This conversation has ended" : "Þessu samtali er lokið",
    "Request password" : "Biðja um lykilorð",
    "Share screen" : "Deila skjá",
    "Show your screen" : "Birta skjáinn þinn",
    "Stop screensharing" : "Hætta skjádeilingu",
    "Error requesting the password." : "Villa kom upp við að biðja um lykilorð.",
    "Please enter the password for this call" : "Settu inn lykilorðið fyrir þetta símtal",
    "Password required" : "Lykilorðs er krafist",
    "Password" : "Lykilorð",
    "Cancel" : "Hætta við",
    "Submit" : "Senda inn",
    "Leave call" : "Hætta símtali",
    "Join call" : "Taka þátt í símtali",
    "Start call" : "Hefja samtal",
    "Share link" : "Deila tengli",
    "Change password" : "Breyta lykilorði",
    "Set password" : "Stilltu lykilorð",
    "Name" : "Nafn",
    "Conversation name" : "Heiti samtals",
    "Rename" : "Endurnefna",
    "Copy link" : "Afrita tengil",
    "Conversation with {name}" : "Samtal við {name}",
    "Error occurred while setting password" : "Villa kom upp við að stilla lykilorð",
    "Link copied!" : "Tengill afritaður!",
    "You" : "Þú",
    "No messages yet, start the conversation!" : "Engin skilaboð ennþá, byrjaðu umræðuna!",
    "New message …" : "Ný skilaboð …",
    "Send" : "Senda",
    "Share" : "Deila",
    "Guest" : "Gestur",
    "[Unknown user name]" : "[nafn óþekkts notanda]",
    "Today" : "Í dag",
    "Yesterday" : "Í gær",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Villa kom upp við að senda inn skilaboð",
    "File to share" : "Skrá til að deila",
    "Error while sharing" : "Villa við deilingu",
    "Edit" : "Breyta",
    "moderator" : "umsjónarmaður",
    "Demote from moderator" : "Láta hætta sem umsjónarmann",
    "Promote to moderator" : "Gera að umsjónarmanni",
    "Remove participant" : "Fjarlægja þátttakanda",
    "Error while removing user from room" : "Villa við að fjarlægja notanda úr spjallsvæði",
    "Add participant …" : "Bæta við þátttakanda…",
    "Favorited" : "Sett í eftirlæti",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "Leave conversation" : "Hætta í samtali",
    "Delete conversation" : "Eyða samtali",
    "No other people in this call" : "Engir aðrir í þessu símtali",
    "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
    "Close" : "Loka",
    "Waiting for camera and microphone permissions" : "Bíð eftir heimildum fyrir hljóðnema og myndavél",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Til að nota þetta forrit, þarftu að gefa vafranum þínum heimild til að nota hljóðnema og myndavél.",
    "Disable video" : "Gera myndskeið óvirk",
    "Show screen" : "Birta skjá",
    "Enable video" : "Virkja myndskeið",
    "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
    "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
    "Access to microphone & camera was denied" : "Aðgangur að hljóðnema og myndavél var ekki heimilaður",
    "WebRTC is not supported in your browser" : "WebRTC er ekki stutt í vafranum þínum",
    "Please use a different browser like Firefox or Chrome" : "Veldu einhvern annan vafra eins og Firefox eða Chrome",
    "Error while accessing microphone & camera" : "Villa kom upp þegar reynt var að opna hljóðnema og myndavél",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ekki stutt í vafranum þínum :-/",
    "{participantName}'s screen" : "Skjár {participantName}",
    "Guest's screen" : "Skjár gests",
    "Your screen" : "Skjárinn þinn",
    "a conversation" : "samtal",
    "(Duration %s)" : "(tímalengd %s)",
    "You attended a call with {user1}" : "Þú varst í símtali við {user1}",
    "_%n guest_::_%n guests_" : ["%n gestur","%n gestir"],
    "You attended a call with {user1} and {user2}" : "Þú varst í símtali við {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Þú varst í símtali við {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Þú varst í símtali við {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Þú varst í símtali við {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n annar","%n aðrir"],
    "{actor} invited you to {call}" : "{actor} bauð þér að taka þátt í {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Þér var boðið að taka þátt í <strong>spjallsvæði</strong> eða hefur fengið <strong>upphringingu</strong>",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Þú endurnefndir samtalið \"%1$s\" sem \"%2$s\"",
    "{actor} started a call" : "{actor} hóf samtal",
    "You started a call" : "Þú hófst samtal",
    "{actor} joined the call" : "{actor} kom inn í samtalið",
    "You joined the call" : "Þú komst inn í samtalið",
    "{actor} left the call" : "{actor} hætti í samtalinu",
    "You left the call" : "Þú hættir í samtalinu",
    "{actor} allowed guests" : "{actor} leyfði gesti",
    "You allowed guests" : "Þú leyfðir gesti",
    "You set a password" : "Þú stilltir lykilorð",
    "{actor} left the conversation" : "{actor} hætti í samtalinu",
    "You promoted {user} to moderator" : "Þú gerðir {user} að umsjónarmanni",
    "%s (guest)" : "%s (gestur)",
    "Talk to %s" : "Tala við %s",
    "_%n other guest_::_%n other guests_" : ["%n annar gestur","%n aðrir gestir"],
    ", " : ", ",
    "%s invited you to a conversation." : "%s bauð þér að taka þátt í samtali.",
    "Conversation invitation" : "Boð í samtal",
    "Join »%s«" : "Taka þátt í »%s«",
    "Join now" : "Taktu þátt núna",
    "{user} sent you a private message" : "{user} sendi þér einkaskilaboð",
    "{user} mentioned you in a private conversation" : "{user} minntist á þig í einkasamtali",
    "%s invited you to a private conversation" : "%s bauð þér að taka þátt í einkasímtali",
    "{user} invited you to a private conversation" : "{user} bauð þér að taka þátt í einkasímtali",
    "%s invited you to a group conversation: %s" : "%s bauð þér að taka þátt í hópsímtali: %s",
    "{user} invited you to a group conversation: {call}" : "{user} bauð þér að taka þátt í hópsímtali: {call}",
    "%s invited you to a group conversation" : "%s bauð þér að taka þátt í hópsímtali",
    "{user} invited you to a group conversation" : "{user} bauð þér að taka þátt í hópsímtali",
    "{user} wants to talk with you" : "{user} vill tala við þig",
    "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
    "A group call has started" : "Hópsímtal er byrjað",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Conversation not found" : "Samtal fannst ekki",
    "Path is already shared with this room" : "Slóðinni er þegar deilt með þessu spjallsvæði",
    "Video & audio-conferencing using WebRTC" : "Mynd- og hljóðfundir með WebRTC",
    "This call is password-protected" : "Þetta samtal er er varið með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "STUN servers" : "STUN-þjónar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
    "TURN server" : "TURN-þjónn",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
    "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
    "Join conversations at any time, any where, on any device." : "Taktu þátt í samtölum hvenær sem er, hvar sem er, á hvaða tæki sem er.",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Video calls" : "Myndsímtöl",
    "(group)" : "(hópur)",
    "New public call" : "Nýtt opinbert símtal",
    "Looking great today! :)" : "Lítur vel út í dag! :)",
    "Time to call your friends" : "Tími til að hringja í vinina",
    "You can set your name on the top right of this page so other participants can identify you better." : "Þú getur stillt þetta þannig að nafnið þitt birtist efst til hægri á þessari síðu svo að aðrir þáttakendur eigi auðveldara með að þekkja þig.",
    "This call has ended" : "Þessu símtali er lokið",
    "Saving failed" : "Vistun mistókst",
    "Add person" : "Bæta við aðila",
    "and you" : "og þú",
    "Please adjust your configuration" : "Endilega athugaðu uppsetninguna þína",
    "{actor} invited you to a private call" : "{actor} bauð þér að taka þátt í einkasímtali",
    "{actor} invited you to a group call" : "{actor} bauð þér að taka þátt í hópsímtali",
    "{actor} invited you to the call {call}" : "{actor} bauð þér að taka þátt í símtalinu {call}",
    "You were invited to a <strong>video call</strong>" : "Þér var boðið að taka þátt í <strong>myndsímtali</strong>",
    "Video call" : "Myndsímtal",
    "Invalid format, must be stunserver:port." : "Ógilt snið, verður að vera stun-þjónn:gátt.",
    "Invalid port specified." : "Ógild gátt tiltekin.",
    "Invalid protocols specified." : "Ógildir samskiptamátar tilgreindir.",
    "%s invited you to a private call" : "%s bauð þér að taka þátt í einkasímtali",
    "{user} invited you to a private call" : "{user} bauð þér að taka þátt í einkasímtali",
    "%s invited you to a group call: %s" : "%s bauð þér að taka þátt í hópsímtali: %s",
    "{user} invited you to a group call: {call}" : "{user} bauð þér að taka þátt í hópsímtali: {call}",
    "%s invited you to a group call" : "%s bauð þér að taka þátt í hópsímtali",
    "{user} invited you to a group call" : "{user} bauð þér að taka þátt í hópsímtali",
    "Fullscreen" : "Fylla skjáinn",
    "Mute audio" : "Þagga hljóð",
    "Smile in 3… 2… 1!" : "Brosa eftir 3… 2… 1!",
    "Choose person …" : "Veldu einstakling …",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN-þjónninn er nauðsynlegur til að þáttakendur geti tengst símtölum. TURN-þjónninn tryggir að tengingin virki jafnvel í gegnum eldveggi.",
    "STUN server" : "STUN-þjónn",
    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a private conversation" : "%s minntist á þig í einkasamtali",
    "%s mentioned you in a group conversation: %s" : "%s minntist á þig í hópsamtali: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} minntist á þig í hópsamtali: {call}",
    "%s mentioned you in a group conversation" : "%s minntist á þig í hópsamtali",
    "{user} mentioned you in a group conversation" : "{user} minntist á þig í hópsamtali",
    "You were mentioned in a group conversation by a deleted user: %s" : "Notandi sem nú er búið að eyða minntist á þig í hópsamtali: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "Notandi sem nú er búið að eyða minntist á þig í hópsamtali: {call}",
    "You were mentioned in a group conversation by a deleted user" : "Notandi sem nú er búið að eyða minntist á þig í hópsamtali",
    "A guest mentioned you in a group conversation: %s" : "Gestur minntist á þig í hópsamtali: %s",
    "A guest mentioned you in a group conversation: {call}" : "Gestur minntist á þig í hópsamtali: {call}",
    "A guest mentioned you in a group conversation" : "Gestur minntist á þig í hópsamtali"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
